package Test::ConfigFromFile;
use Any::Moose;

extends any_moose('X::App::Cmd');

1;
